@@ -10,13 +10,19 @@ roundtrip changes
 
 """
 
-import pytest
+import sys
 
-from .roundtrip import dedent, round_trip, round_trip_dump, round_trip_load
+import pytest  # type: ignore  # NOQA
+from roundtrip import (  # type: ignore
+    dedent,
+    round_trip,
+    round_trip_dump,
+    round_trip_load,
+)
 
 
 class TestComments:
-    def test_no_end_of_file_eol(self):
+    def test_no_end_of_file_eol(self) -> None:
         """not excluding comments caused some problems if at the end of
         the file without a newline. First error, then included \0"""
         x = """\
@@ -25,7 +31,7 @@ class TestComments:
         with pytest.raises(AssertionError):
             round_trip(x, extra='a\n')
 
-    def test_no_comments(self):
+    def test_no_comments(self) -> None:
         round_trip(
             """
         - europe: 10
@@ -35,7 +41,7 @@ class TestComments:
         """
         )
 
-    def test_round_trip_ordering(self):
+    def test_round_trip_ordering(self) -> None:
         round_trip(
             """
         a: 1
@@ -49,7 +55,7 @@ class TestComments:
         """
         )
 
-    def test_complex(self):
+    def test_complex(self) -> None:
         round_trip(
             """
         - europe: 10 # top
@@ -59,7 +65,7 @@ class TestComments:
         """
         )
 
-    def test_dropped(self):
+    def test_dropped(self) -> None:
         s = """\
         # comment
         scalar
@@ -67,7 +73,7 @@ class TestComments:
         """
         round_trip(s, 'scalar\n...\n')
 
-    def test_main_mapping_begin_end(self):
+    def test_main_mapping_begin_end(self) -> None:
         round_trip(
             """
         # C start a
@@ -80,7 +86,7 @@ class TestComments:
         """
         )
 
-    def test_reindent(self):
+    def test_reindent(self) -> None:
         x = """\
         a:
           b:     # comment 1
@@ -96,7 +102,7 @@ class TestComments:
         """
         )
 
-    def test_main_mapping_begin_end_items_post(self):
+    def test_main_mapping_begin_end_items_post(self) -> None:
         round_trip(
             """
         # C start a
@@ -109,7 +115,7 @@ class TestComments:
         """
         )
 
-    def test_main_sequence_begin_end(self):
+    def test_main_sequence_begin_end(self) -> None:
         round_trip(
             """
         # C start a
@@ -122,7 +128,7 @@ class TestComments:
         """
         )
 
-    def test_main_sequence_begin_end_items_post(self):
+    def test_main_sequence_begin_end_items_post(self) -> None:
         round_trip(
             """
         # C start a
@@ -135,7 +141,7 @@ class TestComments:
         """
         )
 
-    def test_main_mapping_begin_end_complex(self):
+    def test_main_mapping_begin_end_complex(self) -> None:
         round_trip(
             """
         # C start a
@@ -150,7 +156,7 @@ class TestComments:
         """
         )
 
-    def test_09(self):  # 2.9 from the examples in the spec
+    def test_09(self) -> None:  # 2.9 from the examples in the spec
         s = """\
         hr: # 1998 hr ranking
           - Mark McGwire
@@ -162,7 +168,7 @@ class TestComments:
         """
         round_trip(s, indent=4, block_seq_indent=2)
 
-    def test_09a(self):
+    def test_09a(self) -> None:
         round_trip(
             """
         hr: # 1998 hr ranking
@@ -175,7 +181,7 @@ class TestComments:
         """
         )
 
-    def test_simple_map_middle_comment(self):
+    def test_simple_map_middle_comment(self) -> None:
         round_trip(
             """
         abc: 1
@@ -185,7 +191,7 @@ class TestComments:
         """
         )
 
-    def test_map_in_map_0(self):
+    def test_map_in_map_0(self) -> None:
         round_trip(
             """
         map1: # comment 1
@@ -195,7 +201,7 @@ class TestComments:
         """
         )
 
-    def test_map_in_map_1(self):
+    def test_map_in_map_1(self) -> None:
         # comment is moved from value to key
         round_trip(
             """
@@ -206,7 +212,7 @@ class TestComments:
         """
         )
 
-    def test_application_arguments(self):
+    def test_application_arguments(self) -> None:
         # application configur
         round_trip(
             """
@@ -221,7 +227,7 @@ class TestComments:
         """
         )
 
-    def test_substitute(self):
+    def test_substitute(self) -> None:
         x = """
         args:
           username: anthon          # name
@@ -238,7 +244,7 @@ class TestComments:
         x = x.replace(': secret          ', ': deleted password')
         assert round_trip_dump(data) == dedent(x)
 
-    def test_set_comment(self):
+    def test_set_comment(self) -> None:
         round_trip(
             """
         !!set
@@ -251,7 +257,7 @@ class TestComments:
         """
         )
 
-    def test_omap_comment_roundtrip(self):
+    def test_omap_comment_roundtrip(self) -> None:
         round_trip(
             """
         !!omap
@@ -262,7 +268,7 @@ class TestComments:
         """
         )
 
-    def test_omap_comment_roundtrip_pre_comment(self):
+    def test_omap_comment_roundtrip_pre_comment(self) -> None:
         round_trip(
             """
         !!omap
@@ -274,7 +280,7 @@ class TestComments:
         """
         )
 
-    def test_non_ascii(self):
+    def test_non_ascii(self) -> None:
         round_trip(
             """
         verbosity: 1                  # 0 is minimal output, -1 none
@@ -298,7 +304,7 @@ class TestComments:
         """
         )
 
-    def test_dump_utf8(self):
+    def test_dump_utf8(self) -> None:
         import ruyaml  # NOQA
 
         x = dedent(
@@ -310,10 +316,14 @@ class TestComments:
         )
         data = round_trip_load(x)
         for utf in [True, False]:
-            y = round_trip_dump(data, default_flow_style=False, allow_unicode=utf)
+            y = round_trip_dump(
+                data,
+                default_flow_style=False,
+                allow_unicode=utf,
+            )
             assert y == x
 
-    def test_dump_unicode_utf8(self):
+    def test_dump_unicode_utf8(self) -> None:
         import ruyaml  # NOQA
 
         x = dedent(
@@ -325,10 +335,14 @@ class TestComments:
         )
         data = round_trip_load(x)
         for utf in [True, False]:
-            y = round_trip_dump(data, default_flow_style=False, allow_unicode=utf)
+            y = round_trip_dump(
+                data,
+                default_flow_style=False,
+                allow_unicode=utf,
+            )
             assert y == x
 
-    def test_mlget_00(self):
+    def test_mlget_00(self) -> None:
         x = """\
         a:
         - b:
@@ -349,7 +363,7 @@ class TestInsertPopList:
     need to move the values to subsequent keys on insert"""
 
     @property
-    def ins(self):
+    def ins(self) -> str:
         return """\
         ab:
         - a      # a
@@ -362,7 +376,7 @@ class TestInsertPopList:
         - 2
         """
 
-    def test_insert_0(self):
+    def test_insert_0(self) -> None:
         d = round_trip_load(self.ins)
         d['ab'].insert(0, 'xyz')
         y = round_trip_dump(d, indent=2)
@@ -381,7 +395,7 @@ class TestInsertPopList:
         """
         )
 
-    def test_insert_1(self):
+    def test_insert_1(self) -> None:
         d = round_trip_load(self.ins)
         d['ab'].insert(4, 'xyz')
         y = round_trip_dump(d, indent=2)
@@ -400,7 +414,7 @@ class TestInsertPopList:
         """
         )
 
-    def test_insert_2(self):
+    def test_insert_2(self) -> None:
         d = round_trip_load(self.ins)
         d['ab'].insert(1, 'xyz')
         y = round_trip_dump(d, indent=2)
@@ -419,7 +433,7 @@ class TestInsertPopList:
         """
         )
 
-    def test_pop_0(self):
+    def test_pop_0(self) -> None:
         d = round_trip_load(self.ins)
         d['ab'].pop(0)
         y = round_trip_dump(d, indent=2)
@@ -437,7 +451,7 @@ class TestInsertPopList:
         """
         )
 
-    def test_pop_1(self):
+    def test_pop_1(self) -> None:
         d = round_trip_load(self.ins)
         d['ab'].pop(1)
         y = round_trip_dump(d, indent=2)
@@ -455,7 +469,7 @@ class TestInsertPopList:
         """
         )
 
-    def test_pop_2(self):
+    def test_pop_2(self) -> None:
         d = round_trip_load(self.ins)
         d['ab'].pop(2)
         y = round_trip_dump(d, indent=2)
@@ -473,7 +487,7 @@ class TestInsertPopList:
         """
         )
 
-    def test_pop_3(self):
+    def test_pop_3(self) -> None:
         d = round_trip_load(self.ins)
         d['ab'].pop(3)
         y = round_trip_dump(d, indent=2)
@@ -495,14 +509,14 @@ class TestInsertPopList:
 # http://stackoverflow.com/a/36970608/1307905
 class TestInsertInMapping:
     @property
-    def ins(self):
+    def ins(self) -> str:
         return """\
         first_name: Art
         occupation: Architect  # This is an occupation comment
         about: Art Vandelay is a fictional character that George invents...
         """
 
-    def test_insert_at_pos_1(self):
+    def test_insert_at_pos_1(self) -> None:
         d = round_trip_load(self.ins)
         d.insert(1, 'last name', 'Vandelay', comment='new key')
         y = round_trip_dump(d)
@@ -516,7 +530,7 @@ class TestInsertInMapping:
         """
         )
 
-    def test_insert_at_pos_0(self):
+    def test_insert_at_pos_0(self) -> None:
         d = round_trip_load(self.ins)
         d.insert(0, 'last name', 'Vandelay', comment='new key')
         y = round_trip_dump(d)
@@ -530,7 +544,7 @@ class TestInsertInMapping:
         """
         )
 
-    def test_insert_at_pos_3(self):
+    def test_insert_at_pos_3(self) -> None:
         # much more simple if done with appending.
         d = round_trip_load(self.ins)
         d.insert(3, 'last name', 'Vandelay', comment='new key')
@@ -547,7 +561,7 @@ class TestInsertInMapping:
 
 
 class TestCommentedMapMerge:
-    def test_in_operator(self):
+    def test_in_operator(self) -> None:
         data = round_trip_load(
             """
         x: &base
@@ -565,7 +579,7 @@ class TestCommentedMapMerge:
         assert data['y']['a'] == 1
         assert 'a' in data['y']
 
-    def test_issue_60(self):
+    def test_issue_60(self) -> None:
         data = round_trip_load(
             """
         x: &base
@@ -576,9 +590,9 @@ class TestCommentedMapMerge:
         )
         assert data['x']['a'] == 1
         assert data['y']['a'] == 1
-        assert str(data['y']) == """ordereddict([('a', 1)])"""
+        assert str(data['y']) == """{'a': 1}"""
 
-    def test_issue_60_1(self):
+    def test_issue_60_1(self) -> None:
         data = round_trip_load(
             """
         x: &base
@@ -590,12 +604,12 @@ class TestCommentedMapMerge:
         )
         assert data['x']['a'] == 1
         assert data['y']['a'] == 1
-        assert str(data['y']) == """ordereddict([('b', 2), ('a', 1)])"""
+        assert str(data['y']) == """{'b': 2, 'a': 1}"""
 
 
 class TestEmptyLines:
     # prompted by issue 46 from Alex Harvey
-    def test_issue_46(self):
+    def test_issue_46(self) -> None:
         yaml_str = dedent(
             """\
         ---
@@ -612,7 +626,7 @@ class TestEmptyLines:
         y = round_trip_dump(d, explicit_start=True)
         assert yaml_str == y
 
-    def test_multispace_map(self):
+    def test_multispace_map(self) -> None:
         round_trip(
             """
         a: 1x
@@ -629,8 +643,8 @@ class TestEmptyLines:
         """
         )
 
-    @pytest.mark.xfail(strict=True)
-    def test_multispace_map_initial(self):
+    @pytest.mark.xfail(strict=True)  # type: ignore
+    def test_multispace_map_initial(self) -> None:
         round_trip(
             """
 
@@ -648,7 +662,7 @@ class TestEmptyLines:
         """
         )
 
-    def test_embedded_map(self):
+    def test_embedded_map(self) -> None:
         round_trip(
             """
         - a: 1y
@@ -658,7 +672,7 @@ class TestEmptyLines:
         """
         )
 
-    def test_toplevel_seq(self):
+    def test_toplevel_seq(self) -> None:
         round_trip(
             """\
         - 1
@@ -669,7 +683,7 @@ class TestEmptyLines:
         """
         )
 
-    def test_embedded_seq(self):
+    def test_embedded_seq(self) -> None:
         round_trip(
             """
         a:
@@ -683,7 +697,7 @@ class TestEmptyLines:
         """
         )
 
-    def test_line_with_only_spaces(self):
+    def test_line_with_only_spaces(self) -> None:
         # issue 54
         yaml_str = "---\n\na: 'x'\n \nb: y\n"
         d = round_trip_load(yaml_str, preserve_quotes=True)
@@ -694,7 +708,7 @@ class TestEmptyLines:
             print(line + '$')
         assert stripped == y
 
-    def test_some_eol_spaces(self):
+    def test_some_eol_spaces(self) -> None:
         # spaces after tokens and on empty lines
         yaml_str = '---  \n  \na: "x"  \n   \nb: y  \n'
         d = round_trip_load(yaml_str, preserve_quotes=True)
@@ -705,7 +719,7 @@ class TestEmptyLines:
             print(line + '$')
         assert stripped == y
 
-    def test_issue_54_not_ok(self):
+    def test_issue_54_not_ok(self) -> None:
         yaml_str = dedent(
             """\
         toplevel:
@@ -717,10 +731,11 @@ class TestEmptyLines:
         d = round_trip_load(yaml_str)
         print(d.ca)
         y = round_trip_dump(d, indent=4)
+        assert isinstance(y, str)
         print(y.replace('\n', '$\n'))
         assert yaml_str == y
 
-    def test_issue_54_ok(self):
+    def test_issue_54_ok(self) -> None:
         yaml_str = dedent(
             """\
         toplevel:
@@ -732,7 +747,7 @@ class TestEmptyLines:
         y = round_trip_dump(d, indent=4)
         assert yaml_str == y
 
-    def test_issue_93(self):
+    def test_issue_93(self) -> None:
         round_trip(
             """\
         a:
@@ -743,7 +758,7 @@ class TestEmptyLines:
         """
         )
 
-    def test_issue_93_00(self):
+    def test_issue_93_00(self) -> None:
         round_trip(
             """\
         a:
@@ -753,7 +768,7 @@ class TestEmptyLines:
         """
         )
 
-    def test_issue_93_01(self):
+    def test_issue_93_01(self) -> None:
         round_trip(
             """\
         - - c1: cat   # a1
@@ -762,7 +777,7 @@ class TestEmptyLines:
         """
         )
 
-    def test_issue_93_02(self):
+    def test_issue_93_02(self) -> None:
         # never failed as there is no indent
         round_trip(
             """\
@@ -772,7 +787,7 @@ class TestEmptyLines:
         """
         )
 
-    def test_issue_96(self):
+    def test_issue_96(self) -> None:
         # inserted extra line on trailing spaces
         round_trip(
             """\
@@ -788,7 +803,8 @@ class TestEmptyLines:
 
 
 class TestUnicodeComments:
-    def test_issue_55(self):  # reported by Haraguroicha Hsu
+    @pytest.mark.skipif(sys.version_info < (2, 7), reason='wide unicode')  # type: ignore
+    def test_issue_55(self) -> None:  # reported by Haraguroicha Hsu
         round_trip(
             """\
         name: TEST
@@ -810,7 +826,7 @@ class TestUnicodeComments:
 
 
 class TestEmptyValueBeforeComments:
-    def test_issue_25a(self):
+    def test_issue_25a(self) -> None:
         round_trip(
             """\
         - a: b
@@ -820,7 +836,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_issue_25a1(self):
+    def test_issue_25a1(self) -> None:
         round_trip(
             """\
         - a: b
@@ -830,7 +846,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_issue_25b(self):
+    def test_issue_25b(self) -> None:
         round_trip(
             """\
         var1: #empty
@@ -838,7 +854,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_issue_25c(self):
+    def test_issue_25c(self) -> None:
         round_trip(
             """\
         params:
@@ -848,7 +864,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_issue_25c1(self):
+    def test_issue_25c1(self) -> None:
         round_trip(
             """\
         params:
@@ -859,7 +875,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_issue_25_00(self):
+    def test_issue_25_00(self) -> None:
         round_trip(
             """\
         params:
@@ -868,7 +884,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_issue_25_01(self):
+    def test_issue_25_01(self) -> None:
         round_trip(
             """\
         a:        # comment 1
@@ -878,7 +894,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_issue_25_02(self):
+    def test_issue_25_02(self) -> None:
         round_trip(
             """\
         a:        # comment 1
@@ -887,7 +903,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_issue_25_03(self):
+    def test_issue_25_03(self) -> None:
         s = """\
         a:        # comment 1
                   #  comment 2
@@ -895,7 +911,7 @@ class TestEmptyValueBeforeComments:
         """
         round_trip(s, indent=4, block_seq_indent=2)
 
-    def test_issue_25_04(self):
+    def test_issue_25_04(self) -> None:
         round_trip(
             """\
         a:        # comment 1
@@ -904,7 +920,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_flow_seq_within_seq(self):
+    def test_flow_seq_within_seq(self) -> None:
         round_trip(
             """\
         # comment 1
@@ -921,7 +937,7 @@ class TestEmptyValueBeforeComments:
         """
         )
 
-    def test_comment_after_block_scalar_indicator(self):
+    def test_comment_after_block_scalar_indicator(self) -> None:
         round_trip(
             """\
         a: | # abc
@@ -944,7 +960,7 @@ a: |
 
 class TestBlockScalarWithComments:
     # issue 99 reported by Colm O'Connor
-    def test_scalar_with_comments(self):
+    def test_scalar_with_comments(self) -> None:
         import ruyaml  # NOQA
 
         for x in [
@@ -957,7 +973,6 @@ class TestBlockScalarWithComments:
             '# abc\n\n#xyz\n',
             '\n\n  # abc\n  #xyz\n',
         ]:
-
             commented_line = test_block_scalar_commented_line_template.format(x)
             data = round_trip_load(commented_line)
 
