@@ -1,4 +1,5 @@
-# coding: utf-8
+from __future__ import annotations
+
 if False:  # MYPY
     from typing import Any, Dict, Iterator, List, Optional, Union  # NOQA
 
@@ -9,12 +10,10 @@ class Anchor:
     __slots__ = 'value', 'always_dump'
     attrib = anchor_attrib
 
-    def __init__(self):
-        # type: () -> None
+    def __init__(self) -> None:
         self.value = None
         self.always_dump = False
 
-    def __repr__(self):
-        # type: () -> Any
+    def __repr__(self) -> Any:
         ad = ', (always dump)' if self.always_dump else ""
-        return 'Anchor({!r}{})'.format(self.value, ad)
+        return f'Anchor({self.value!r}{ad})'
